@@ -13,7 +13,7 @@ import re, sys, os, time
 from xml.dom import minidom
 from optparse import OptionParser
 
-VERSION = '1.3'
+VERSION = '1.4'
 __all__ = ['LcovCobertura']
 
 class LcovCobertura(object):
@@ -211,6 +211,10 @@ class LcovCobertura(object):
         })
 
         sources = self._el(document, 'sources', {})
+        source = self._el(document, 'source', {})
+        source.appendChild(document.createTextNode(self.base_dir))
+        sources.appendChild(source)
+
         root.appendChild(sources)
 
         packages_el = self._el(document, 'packages', {})
